#' Create a CSV file to be used in cellranger aggr after completing all count pipelines
#' Project: AZIMUT
#' Author: Nicolas Vallet

#' Require
library(tidyverse)

#' Define samples to aggregate
samples = c("18A", "18D", "18N",
            "30A", "30D", "30N",
            "23A", "23D", "23N",
            "36A", "36D", "36N",
            "37A", "37D", "37N",
            "38A", "38D", "38N",
            "32A", "32D", "32N",
            "39A", "39D", "39N",
            "35A", "35D", "35N",
            "40A", "40D", "40N")

#' Define initial path to files
path_folder = "/home/nivall/yard/run_cellranger_aggr/"
path_to_samples = paste0( path_folder, "molecule_info_",samples,".h5")

#' Create the table to be transformed in csv format
aggr = tibble(samples, path_to_samples) %>%
    add_column(condition = "na", sample_names = "na") %>%    
    mutate(condition = if_else(grepl("A",samples),
                               true = "AZM",
                               false = if_else(grepl("D", samples),
                                               true = "CTRL",
                                               false = "US"
                                               )
                               )
           ) %>%
    mutate(sample_names = paste0("HD",substr(samples, start = 1, stop = 2) ) ) %>%
    rename(sample_id = samples, molecule_h5 = path_to_samples)
write_csv(aggr, "~/tmp/aggr_libraries.csv")
