#' This script aims at performing differential expression among prolif clusters
#' Projet: AZIMUT
#' Author: Nicolas Vallet

#' Require
library(Seurat)
library(tidyverse)

#' set paths 
path_to_rds  = "~/scrna_files"
path_to_save = "~/Git/azimutscrna/res"

#' Read RDS file with clustered
setwd(path_to_rds)
prolif = readRDS( "prolif_adtclust_cyclecell.RData" )

#' List of individual clusters
cluster_list = c(1, 9, 15, 17, 7, 8, 12, 19, 3, 5, 0, 25)

#' Extract data
setwd(path_to_save)
iteration = 1
for(cluster in cluster_list) {
    ## message info
    message("Performing differential analysis in cluster#",cluster," (",iteration,"/",length(cluster_list),")")
    ## set name to save file
    output_name = paste0("diffexpr_clust",cluster,".csv")
    ## subset seurat object to cluster
    clust = subset(prolif, idents = cluster)
    ## change cell annotation according to condition
    Idents(clust) = clust@meta.data$condition
    ## change default assay
    DefaultAssay(clust) = "RNA"
    ## compte differential expression test
    clust_mk = FindMarkers(clust, ident.1 = "AZM", ident.2 = "CTRL", logfc.threshold = 0.05)
    ## save result
    write.csv2(clust_mk, file = output_name)
}

#' Extract CD4+ and CD8+ differences
## List of CD4 and CD8 clusters
cluster_list = list()
cluster_list[["cd4"]] = c(1, 9, 15, 5, 0)
cluster_list[["cd8"]] = c(17, 7, 19, 3)

#' Extract data
Idents(prolif) = prolif@meta.data$seurat_clusters
setwd(path_to_save)
iteration = 1
for(cluster in cluster_list) {
    ## message info
    name_i = names(cluster_list)[[iteration]]
    message("Performing differential analysis in cluster list",name_i," (",iteration,"/",length(cluster_list),")")
    ## set name to save file
    output_name = paste0("diffexpr_clust",name_i,".csv")
    ## subset seurat object to cluster
    clust = subset(prolif, idents = cluster)
    ## change cell annotation according to condition
    Idents(clust) = clust@meta.data$condition
    ## change default assay
    DefaultAssay(clust) = "RNA"
    ## compte differential expression test
    clust_mk = FindMarkers(clust, ident.1 = "AZM", ident.2 = "CTRL", logfc.threshold = 0.001)
    ## save result
    write.csv2(clust_mk, file = output_name)
    ## next iteration
    iteration = iteration + 1
}

#' Extract bulk differences
## merge all stim clusters
output_name = "diffexpr_bulk_stim.csv"
stim = subset(prolif, idents = cluster_list)
Idents(stim) = stim@meta.data$condition
DefaultAssay(stim) = "RNA"
clust_mk = FindMarkers(stim, ident.1 = "AZM", ident.2 = "CTRL", logfc.threshold = 0.001)
write.csv2(clust_mk, file = output_name)
