#' Draw pie-chart of n cells studied in each condition
#' Project: AZIMUT
#' Author: Nicolas Vallet

#' Require
library(Seurat)
library(ggplot2)
library(RColorBrewer)
library(tidyverse)

#' Defining path
path_to_rds  = "~/scrna_files"
path_to_save = "~/tmp"
output_file_name = "piechart.pdf"

#' Read RDS file with clustered cells
setwd(path_to_rds)
prolif = readRDS( "prolif_adtclust_cyclecell.RData" )

#' Get n cells and transform to dataframe
ncells = prolif@meta.data$condition %>%
    table() %>%
    as.data.frame() %>%
    rename(condition = 1) 

#' Plot the piechart
piechart = ncells %>%
    ggplot( aes(x = "", y=Freq, fill=condition)) +
    geom_bar(stat="identity", width=1, color="white") +
    coord_polar("y", start=0) +
    theme_void() + 
    theme(legend.position="none") +
    scale_fill_manual(values = c("#666666ff", "#d3bcecff", "#6a3d9aff") )

#' Save result
setwd(path_to_save)
pdf(output_file_name, width = 4, height = 4)
print(piechart)
dev.off()
