#' This script aims at plotting umap from seurat object
#' Projet: AZIMUT
#' Author: Nicolas Vallet

#' Require
library(Seurat)
library(tidyverse)
library(RColorBrewer)

#' Defining path
path_to_rds  = "~/scrna_files"
path_to_save = "~/tmp"

#' Read RDS file with clustered cells
setwd(path_to_rds)
prolif = readRDS( "prolif_adtclust_cyclecell.RData" )

#' Print UMAP embedded with clusters
setwd(path_to_save)
Idents(prolif) = prolif@meta.data$seurat_clusters
#cols = brewer.pal(12, "Paired") %>% append(brewer.pal(11, "Paired")) %>% append(brewer.pal(3, "Paired"))
plot = DimPlot(prolif, reduction = "umap") + NoLegend()
to_plot = LabelClusters(plot = plot, id = "ident")
pdf("umap_clusters.pdf", width = 4, height = 4)
print(to_plot)
dev.off()
png("umap_clust_nolab.png", width = 4, height = 4, res = 600, unit = "in")
print(plot)
dev.off()

#' Print UMAP according to activated and non activated cells (merged)
prolif@meta.data$stim = ifelse(prolif@meta.data$condition == "US",
                               "Unstimulated",
                               "Stimulated")
table(prolif@meta.data$stim, prolif@meta.data$condition)
Idents(prolif) = prolif@meta.data$stim
plot = DimPlot(prolif, reduction = "umap", cols = c("#6A3D9A", "#666666") ) + NoLegend()
to_plot = LabelClusters(plot = plot, id = "ident")
pdf("umap_stim_merged.pdf", width = 4, height = 4)
print(to_plot)
dev.off()
png("umap_stim_inks.png", width = 4, height = 4, res = 600, unit = "in")
print(plot)
dev.off()


#' Print UMAP according to activated and non activated cells (merged)
prolif@meta.data$stim = ifelse(prolif@meta.data$condition == "US",
                               "Unstimulated",
                               "Stimulated")
table(prolif@meta.data$stim, prolif@meta.data$condition)
Idents(prolif) = prolif@meta.data$stim
to_plot = DimPlot(prolif, reduction = "umap", split.by = "ident", cols = c("#6A3D9A", "#666666") )
pdf("umap_stim.pdf", width = 8, height = 4)
print(to_plot)
dev.off()
png("umap_stimsplit_inks.png", width = 8, height = 4, res = 600, unit = "in")
print(to_plot)
dev.off()
